@@ -18,7 +18,9 @@ convertParamSetToIrace = function(par.set, digits = 4, as.chars = FALSE) {
   assertFlag(as.chars)
   if (!is.null(par.set$forbidden))
     stopf("Operation not allowed for param set with forbidden region currently!")
-  requirePackages("irace", "convertParamSetToIrace")
+  if (!hasFiniteBoxConstraints(par.set))
+    stop("convertParamSetToIrace requires finite box constraints for all numeric and integer params!")
+  requirePackages("irace", why = "convertParamSetToIrace", default.method = "load")
   lines = character(0)
   fnum = function(x) formatC(x, format = "f", digits = digits)
   count = 1
